@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -154,7 +154,7 @@ sub generate {
 
     # Determine if we should skip certain notes given the chord flavor
     my @tones = get_scale_notes($chord_note, $scale);
-    print "\tSCALE: ", ddc(\@tones) if $self->verbose;
+    print "\t$scale SCALE: ", ddc(\@tones) if $self->verbose;
     my @fixed;
     for my $p (@pitches) {
         my $n = Music::Note->new($p, 'midinum');
@@ -277,7 +277,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
